[PATCH] D26166: [Sema] Don't issue analysis-based warnings when a fatal error has occurred

Akira Hatanaka via cfe-commits cfe-commits at lists.llvm.org
Mon Oct 31 22:41:00 PDT 2016


ahatanak updated this revision to Diff 76521.
ahatanak added a comment.

Thanks, that fixed the failing regression tests.


https://reviews.llvm.org/D26166

Files:
  lib/Sema/SemaTemplateInstantiate.cpp
  test/SemaCXX/instantiate-template-fatal-error.cpp


Index: test/SemaCXX/instantiate-template-fatal-error.cpp
===================================================================
--- /dev/null
+++ test/SemaCXX/instantiate-template-fatal-error.cpp
@@ -0,0 +1,22 @@
+// RUN: %clang_cc1 -fsyntax-only -verify -std=c++14 %s
+
+#pragma clang diagnostic fatal "-Wall"
+#pragma clang diagnostic fatal "-Wold-style-cast"
+
+template <class T> bool foo0(const long long *a, T* b) {
+  return a == (const long long*)b; // expected-error {{use of old-style cast}}
+}
+
+template<class T>
+struct S1 {
+};
+
+template<class T>
+struct S2 : S1<T> {
+  bool m1(const long long *a, T *b) const { return foo0(a, b); }
+};
+
+bool foo1(const long long *a, int *b) {
+  S2<int> s2;
+  return s2.m1(a, b);
+}
Index: lib/Sema/SemaTemplateInstantiate.cpp
===================================================================
--- lib/Sema/SemaTemplateInstantiate.cpp
+++ lib/Sema/SemaTemplateInstantiate.cpp
@@ -209,9 +209,11 @@
     sema::TemplateDeductionInfo *DeductionInfo)
     : SemaRef(SemaRef), SavedInNonInstantiationSFINAEContext(
                             SemaRef.InNonInstantiationSFINAEContext) {
-  // Don't allow further instantiation if a fatal error has occcured.  Any
-  // diagnostics we might have raised will not be visible.
-  if (SemaRef.Diags.hasFatalErrorOccurred()) {
+  // Don't allow further instantiation if a fatal error and an uncompilable
+  // error have occcured. Any diagnostics we might have raised will not be
+  // visible.
+  if (SemaRef.Diags.hasFatalErrorOccurred() &&
+      SemaRef.Diags.hasUncompilableErrorOccurred()) {
     Invalid = true;
     return;
   }


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D26166.76521.patch
Type: text/x-patch
Size: 1629 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20161101/f434f658/attachment.bin>


More information about the cfe-commits mailing list